==> geocoder-0.8.4.zip: geocoder-0.8.4/geocoder/location.py <==
#!/usr/bin/python
# coding: utf8

from .google import Google


class Location(object):
    """ Location container """

    lat = None
    lng = None
    latlng = None

    def __init__(self, location):
        self.name = location

        # Functions
        self.lat, self.lng = self._check_input(location)

    def __repr__(self):
        return '<Location [{0}]>'.format(self.name)

    def _convert_float(self, number):
        try:
            return float(number)
        except ValueError:
            return None

    def _check_input(self, location):
        lat, lng = 0.0, 0.0

        # Checking for a String
        if isinstance(location, str):
            g = Google(location)
            lat, lng = g.lat, g.lng

        # Checking for List of Tuple
        if isinstance(location, (list, tuple)):
            lat, lng = self._check_for_list(location)

        # Checking for Dictionary
        elif isinstance(location, dict):
            lat, lng = self._check_for_dict(location)

        # Checking for a Geocoder Class
        elif hasattr(location, 'latlng'):
            lat, lng = location.latlng

        # Return Results
        return lat, lng

    def _check_for_list(self, location):
        # Standard LatLng list or tuple with 2 number values
        if len(location) == 2:
            lat = self._convert_float(location[0])
            lng = self._convert_float(location[1])
            if bool(lat and lng):
                return lat, lng

    def _check_for_dict(self, location):
        # Standard LatLng list or tuple with 2 number values
        if bool('lat' in location and 'lng' in location):
            lat = self._convert_float(location.get('lat'))
            lng = self._convert_float(location.get('lng'))
            if bool(lat and lng):
                return lat, lng

    @property
    def latlng(self):
        return '{0},{1}'.format(self.lat, self.lng)


if __name__ == '__main__':
    pass

==> geocoder-1.0.0.zip: geocoder-1.0.0/geocoder/location.py <==
#!/usr/bin/python
# coding: utf8


class Location(object):
    """ Location container """

    lat = None
    lng = None
    latlng = None

    def __init__(self, location):
        self.name = location

        # Functions
        self.lat, self.lng = self._check_input(location)

    def __repr__(self):
        return '<Location [{0}]>'.format(self.name)

    def _convert_float(self, number):
        try:
            return float(number)
        except ValueError:
            return None

    def _check_input(self, location):
        lat, lng = 0.0, 0.0

        # Checking for a String
        if isinstance(location, str):
            """
            Building Regex for '45.123,-76.123' Lat & Lng
            [#85 Issue]
            """
            pass

        # Checking for List of Tuple
        if isinstance(location, (list, tuple)):
            lat, lng = self._check_for_list(location)

        # Checking for Dictionary
        elif isinstance(location, dict):
            lat, lng = self._check_for_dict(location)

        # Checking for a Geocoder Class
        elif hasattr(location, 'latlng'):
            lat, lng = location.latlng

        # Return Results
        return lat, lng

    def _check_for_list(self, location):
        # Standard LatLng list or tuple with 2 number values
        if len(location) == 2:
            lat = self._convert_float(location[0])
            lng = self._convert_float(location[1])
            if bool(lat and lng):
                return lat, lng

    def _check_for_dict(self, location):
        # Standard LatLng list or tuple with 2 number values
        if bool('lat' in location and 'lng' in location):
            lat = self._convert_float(location.get('lat'))
            lng = self._convert_float(location.get('lng'))
            if bool(lat and lng):
                return lat, lng

    @property
    def latlng(self):
        return '{0},{1}'.format(self.lat, self.lng)


if __name__ == '__main__':
    pass
